@@ -4,6 +4,7 @@
 #include "utils/FileSystemUtil.h"
 #include "utils/StringUtil.h"
 #include "views/gamelist/IGameListView.h"
+#include "views/gamelist/ISimpleGameListView.h"
 #include "views/ViewController.h"
 #include "FileData.h"
 #include "FileFilterIndex.h"
@@ -124,7 +125,7 @@ void CollectionSystemManager::saveCustomCollection(SystemData* sys)
 
 /* Methods to load all Collections into memory, and handle enabling the active ones */
 // loads all Collection Systems
-void CollectionSystemManager::loadCollectionSystems()
+void CollectionSystemManager::loadCollectionSystems(bool async)
 {
 	initAutoCollectionSystems();
 	CollectionSystemDecl decl = mCollectionSystemDeclsIndex[myCollectionsName];
@@ -135,8 +136,10 @@ void CollectionSystemManager::loadCollectionSystems()
 	{
 		// Now see which ones are enabled
 		loadEnabledListFromSettings();
+
 		// add to the main System Vector, and create Views as needed
-		updateSystemsList();
+		if (!async)
+			updateSystemsList();
 	}
 }
 
@@ -144,7 +147,7 @@ void CollectionSystemManager::loadCollectionSystems()
 void CollectionSystemManager::loadEnabledListFromSettings()
 {
 	// we parse the auto collection settings list
-	std::vector<std::string> autoSelected = Utils::String::commaStringToVector(Settings::getInstance()->getString("CollectionSystemsAuto"), true);
+	std::vector<std::string> autoSelected = Utils::String::delimitedStringToVector(Settings::getInstance()->getString("CollectionSystemsAuto"), ",", true);
 
 	// iterate the map
 	for(std::map<std::string, CollectionSystemData>::iterator it = mAutoCollectionSystemsData.begin() ; it != mAutoCollectionSystemsData.end() ; it++ )
@@ -153,7 +156,7 @@ void CollectionSystemManager::loadEnabledListFromSettings()
 	}
 
 	// we parse the custom collection settings list
-	std::vector<std::string> customSelected = Utils::String::commaStringToVector(Settings::getInstance()->getString("CollectionSystemsCustom"), true);
+	std::vector<std::string> customSelected = Utils::String::delimitedStringToVector(Settings::getInstance()->getString("CollectionSystemsCustom"), ",", true);
 
 	// iterate the map
 	for(std::map<std::string, CollectionSystemData>::iterator it = mCustomCollectionSystemsData.begin() ; it != mCustomCollectionSystemsData.end() ; it++ )
@@ -257,7 +260,7 @@ void CollectionSystemManager::updateCollectionSystem(FileData* file, CollectionS
 			// found and we are removing
 			if (name == "favorites" && file->metadata.get("favorite") == "false") {
 				// need to check if still marked as favorite, if not remove
-				ViewController::get()->getGameListView(curSys).get()->remove(collectionEntry, false);
+				ViewController::get()->getGameListView(curSys).get()->remove(collectionEntry, false, true);
 			}
 			else
 			{
@@ -295,8 +298,9 @@ void CollectionSystemManager::trimCollectionCount(FileData* rootFolder, int limi
 	while ((int)rootFolder->getChildrenListToDisplay().size() > limit)
 	{
 		CollectionFileData* gameToRemove = (CollectionFileData*)rootFolder->getChildrenListToDisplay().back();
-		ViewController::get()->getGameListView(curSys).get()->remove(gameToRemove, false);
+		ViewController::get()->getGameListView(curSys).get()->remove(gameToRemove, false, false);
 	}
+	ViewController::get()->onFileChanged(rootFolder, FILE_REMOVED);
 }
 
 // deletes all collection files from collection systems related to the source file
@@ -320,7 +324,7 @@ void CollectionSystemManager::deleteCollectionFiles(FileData* file)
 				sysDataIt->second.needsSave = true;
 				FileData* collectionEntry = children.at(key);
 				SystemData* systemViewToUpdate = getSystemToView(sysDataIt->second.system);
-				ViewController::get()->getGameListView(systemViewToUpdate).get()->remove(collectionEntry, false);
+				ViewController::get()->getGameListView(systemViewToUpdate).get()->remove(collectionEntry, false, true);
 			}
 		}
 	}
@@ -453,7 +457,7 @@ void CollectionSystemManager::exitEditMode()
 }
 
 // adds or removes a game from a specific collection
-bool CollectionSystemManager::toggleGameInCollection(FileData* file)
+bool CollectionSystemManager::toggleGameInCollection(FileData* file, int presscount)
 {
 	if (file->getType() == GAME)
 	{
@@ -479,6 +483,9 @@ bool CollectionSystemManager::toggleGameInCollection(FileData* file)
 			SystemData* systemViewToUpdate = getSystemToView(sysData);
 
 			if (found) {
+				if (needDoublePress(presscount)) {
+					return true;
+				}
 				adding = false;
 				// if we found it, we need to remove it
 				FileData* collectionEntry = children.at(key);
@@ -489,7 +496,7 @@ bool CollectionSystemManager::toggleGameInCollection(FileData* file)
 				{
 					systemViewToUpdate->getIndex()->removeFromIndex(collectionEntry);
 				}
-				ViewController::get()->getGameListView(systemViewToUpdate).get()->remove(collectionEntry, false);
+				ViewController::get()->getGameListView(systemViewToUpdate).get()->remove(collectionEntry, false, true);
 			}
 			else
 			{
@@ -519,6 +526,9 @@ bool CollectionSystemManager::toggleGameInCollection(FileData* file)
 			}
 			else
 			{
+				if (needDoublePress(presscount)) {
+					return true;
+				}
 				adding = false;
 				md->set("favorite", "false");
 			}
@@ -542,6 +552,7 @@ bool CollectionSystemManager::toggleGameInCollection(FileData* file)
 	return false;
 }
 
+
 SystemData* CollectionSystemManager::getSystemToView(SystemData* sys)
 {
 	SystemData* systemToView = sys;
@@ -803,16 +814,19 @@ void CollectionSystemManager::removeCollectionsFromDisplayedSystems()
 
 	// remove all custom collections in bundle
 	// this should not delete the objects from memory!
-	FileData* customRoot = mCustomCollectionsBundle->getRootFolder();
-	std::vector<FileData*> mChildren = customRoot->getChildren();
-	for(auto it = mChildren.cbegin(); it != mChildren.cend(); it++)
+	if (mCustomCollectionsBundle)
 	{
-		customRoot->removeChild(*it);
+		FileData* customRoot = mCustomCollectionsBundle->getRootFolder();
+		std::vector<FileData*> mChildren = customRoot->getChildren();
+		for(auto it = mChildren.cbegin(); it != mChildren.cend(); it++)
+		{
+			customRoot->removeChild(*it);
+		}
+		// clear index
+		mCustomCollectionsBundle->getIndex()->resetIndex();
+		// remove view so it's re-created as needed
+		ViewController::get()->removeGameListView(mCustomCollectionsBundle);
 	}
-	// clear index
-	mCustomCollectionsBundle->getIndex()->resetIndex();
-	// remove view so it's re-created as needed
-	ViewController::get()->removeGameListView(mCustomCollectionsBundle);
 }
 
 void CollectionSystemManager::addEnabledCollectionsToDisplayedSystems(std::map<std::string, CollectionSystemData>* colSystemData)
@@ -1038,6 +1052,17 @@ bool CollectionSystemManager::includeFileInAutoCollections(FileData* file)
 	return file->getName() != "kodi" && file->getSystem()->isGameSystem();
 }
 
+
+bool CollectionSystemManager::needDoublePress(int presscount) {
+	if (Settings::getInstance()->getBool("DoublePressRemovesFromFavs") && presscount < 2) {
+		GuiInfoPopup* toast = new GuiInfoPopup(mWindow, "Press again to remove from '" + Utils::String::toUpper(mEditingCollection)
+		+ "'", ISimpleGameListView::DOUBLE_PRESS_DETECTION_DURATION, 100, 200);
+		mWindow->setInfoPopup(toast);
+		return true;
+	}
+	return false;
+}
+
 std::string getCustomCollectionConfigPath(std::string collectionName)
 {
 	return getCollectionsFolder() + "/custom-" + collectionName + ".cfg";
